@@ -1,47 +1,29 @@
 from Acquisition import aq_parent
 from OFS.SimpleItem import SimpleItem
-from Products.CMFPlone.utils import safe_unicode
-from Products.Five.browser import BrowserView
+from plone.app.event.base import dt_end_of_day
+from plone.app.event.base import dt_start_of_day
 from plone.app.event.base import guess_date_from
+from plone.base.utils import safe_text
 from plone.event.interfaces import IEventAccessor
 from plone.event.interfaces import IEventRecurrence
 from plone.event.interfaces import IOccurrence
 from plone.event.interfaces import IRecurrenceSupport
 from plone.event.recurrence import recurrence_sequence_ical
 from plone.event.utils import is_same_day
-from plone.namedfile.scaling import ImageScale as DXImageScaling
-from zope.component import adapts
-from zope.interface import Interface
-from zope.interface import implements
+from plone.event.utils import pydt
+from plone.namedfile.interfaces import IImageScaleTraversable
+from plone.namedfile.scaling import ImageScaling
+from Products.Five.browser import BrowserView
+from zope.component import adapter
+from zope.interface import implementer
 from zope.publisher.interfaces.browser import IBrowserRequest
-
-try:
-    from repoze.zope2.publishtraverse import DefaultPublishTraverse
-except ImportError:
-    from ZPublisher.BaseRequest import DefaultPublishTraverse
-
-try:
-    from plone.app.event.at.interfaces import IATEvent
-except ImportError:
-    class IATEvent(Interface):
-        pass
-try:
-    from plone.app.event.dx.interfaces import IDXEvent
-except ImportError:
-    class IDXEvent(Interface):
-        pass
-
-try:
-    from plone.app.imaging.scaling import ImageScaling as ATImageScaling
-except ImportError:
-    pass
+from ZPublisher.BaseRequest import DefaultPublishTraverse
 
 
-class RecurrenceSupport(object):
-    """IRecurrenceSupport Adapter.
-    """
-    implements(IRecurrenceSupport)
-    adapts(IEventRecurrence)
+@adapter(IEventRecurrence)
+@implementer(IRecurrenceSupport)
+class RecurrenceSupport:
+    """IRecurrenceSupport Adapter."""
 
     def __init__(self, context):
         self.context = context
@@ -61,6 +43,7 @@ class RecurrenceSupport(object):
 
         Please note: Events beginning before range_start but ending afterwards
                      won't be found.
+
         TODO: really?
 
         TODO: test with event start = 21st feb, event end = start+36h,
@@ -68,21 +51,38 @@ class RecurrenceSupport(object):
         """
         event = IEventAccessor(self.context)
 
+        # We try to get IEventBasic start without including recurrence
+        event_start = getattr(self.context, "start", None)
+        if not event_start:
+            event_start = event.start
+        elif getattr(event, "whole_day", None):
+            event_start = dt_start_of_day(event_start)
+
         # We get event ends by adding a duration to the start. This way, we
         # prevent that the start and end lists are of different size if an
         # event starts before range_start but ends afterwards.
-        duration = event.duration
+        if getattr(event, "open_end", None):
+            event_end = dt_end_of_day(event_start)
+        elif getattr(event, "whole_day", None):
+            event_end = dt_end_of_day(getattr(self.context, "end", None))
+        else:
+            event_end = getattr(self.context, "end", None)
 
-        starts = recurrence_sequence_ical(event.start,
-                                          recrule=event.recurrence,
-                                          from_=range_start, until=range_end,
-                                          duration=duration)
+        duration = event_end - event_start
+
+        starts = recurrence_sequence_ical(
+            event_start,
+            recrule=event.recurrence,
+            from_=range_start,
+            until=range_end,
+            duration=duration,
+        )
 
         # XXX potentially occurrence won't need to be wrapped anymore
         # but doing it for backwards compatibility as views/templates
         # still rely on acquisition-wrapped objects.
         def get_obj(start):
-            if event.start.replace(microsecond=0) == start:
+            if pydt(event_start.replace(microsecond=0)) == start:
                 # If the occurrence date is the same as the event object, the
                 # occurrence is the event itself. return it as such.
                 # Dates from recurrence_sequence_ical are explicitly without
@@ -90,21 +90,20 @@ class RecurrenceSupport(object):
                 # remove it for a valid comparison.
                 return self.context
             return Occurrence(
-                id=str(start.date()),
-                start=start,
-                end=start + duration).__of__(self.context)
+                id=str(start.date()), start=start, end=start + duration
+            ).__of__(self.context)
 
         for start in starts:
             yield get_obj(start)
 
 
+@adapter(IEventRecurrence, IBrowserRequest)
 class OccurrenceTraverser(DefaultPublishTraverse):
     """Generic Occurrence traverser.
 
     Please note: the .at and .dx subpackages implement their own Occurrence
     traversers.
     """
-    adapts(IEventRecurrence, IBrowserRequest)
 
     def publishTraverse(self, request, name):
         context = self.context
@@ -112,43 +111,41 @@ class OccurrenceTraverser(DefaultPublishTraverse):
         if dateobj:
             occs = IRecurrenceSupport(context).occurrences(range_start=dateobj)
             try:
-                occurrence = occs.next()
+                occurrence = next(occs)
                 occ_acc = IEventAccessor(occurrence)
                 if is_same_day(dateobj, occ_acc.start):
                     return occurrence
             except StopIteration:
-                # if no occurrences are defined, use fallbackTraverse
                 pass
         return self.fallbackTraverse(request, name)
 
     def fallbackTraverse(self, request, name):
-        return super(OccurrenceTraverser, self).publishTraverse(request, name)
+        return super().publishTraverse(request, name)
 
 
+@implementer(IOccurrence)
 class Occurrence(SimpleItem):
     """Transient Occurrence object, representing an individual event in a
     recurrecne set.
     """
-    implements(IOccurrence)
 
     def __init__(self, id, start, end):
         self.id = id
         self.start = start
         self.end = end
-        self.portal_type = 'Occurrence'
+        self.portal_type = "Occurrence"
 
 
-class EventOccurrenceAccessor(object):
-    """Generic event accessor adapter implementation for Occurrence objects.
-    """
-    implements(IEventAccessor)
-    adapts(IOccurrence)
+@adapter(IOccurrence)
+@implementer(IEventAccessor)
+class EventOccurrenceAccessor:
+    """Generic event accessor adapter implementation for Occurrence objects."""
 
     def __init__(self, context):
-        object.__setattr__(self, 'context', context)
+        object.__setattr__(self, "context", context)
 
-        own_attr = ['start', 'end', 'url']
-        object.__setattr__(self, '_own_attr', own_attr)
+        own_attr = ["start", "end", "url"]
+        object.__setattr__(self, "_own_attr", own_attr)
 
     def _get_context(self, name):
         # TODO: save parent context on self, so it must not be called every
@@ -174,17 +171,16 @@ class EventOccurrenceAccessor(object):
 
     @property
     def url(self):
-        return safe_unicode(self.context.absolute_url())
+        return safe_text(self.context.absolute_url())
 
 
 class ImageScalingViewFactory(BrowserView):
-    """Factory for ImageScaling view for occurrences.
-    Delegates to AT or DX specific view and rebinds to the parent context.
+    """Factory for ImageScaling view for Occurrences.
+    Delegates to parent @@images view.
     """
+
     def __new__(cls, context, request):
         parent = aq_parent(context)
-        if IATEvent.providedBy(parent):
-            return ATImageScaling(parent, request)
-        elif IDXEvent.providedBy(parent):
-            return DXImageScaling(parent, request)
+        if IImageScaleTraversable.providedBy(parent):
+            return ImageScaling(parent, request)
         return None
