@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from plone.app.event.interfaces import IBrowserLayer
 from plone.app.robotframework.testing import AUTOLOGIN_LIBRARY_FIXTURE
 from plone.app.testing import FunctionalTesting
@@ -6,22 +5,14 @@ from plone.app.testing import IntegrationTesting
 from plone.app.testing import PLONE_FIXTURE
 from plone.app.testing import PloneSandboxLayer
 from plone.registry.interfaces import IRegistry
+from plone.testing.zope import installProduct
+from plone.testing.zope import uninstallProduct
+from plone.testing.zope import WSGI_SERVER_FIXTURE
 from zope.component import getUtility
 from zope.interface import alsoProvides
 
 import os
 
-try:
-    # plone.testing 7+, Plone 5.2+
-    from plone.testing.zope import WSGI_SERVER_FIXTURE
-    from plone.testing.zope import installProduct
-    from plone.testing.zope import uninstallProduct
-except ImportError:
-    # plone.testing 6-, Plone 5.1
-    from plone.testing.z2 import ZSERVER_FIXTURE as WSGI_SERVER_FIXTURE
-    from plone.testing.z2 import installProduct
-    from plone.testing.z2 import uninstallProduct
-
 
 def set_browserlayer(request):
     """Set the BrowserLayer for the request.
@@ -37,22 +28,22 @@ def set_timezone(tz):
     if tz is None:
         return None
     reg = getUtility(IRegistry)
-    current_tz = reg.get('plone.portal_timezone', None)
-    reg['plone.portal_timezone'] = tz
+    current_tz = reg.get("plone.portal_timezone", None)
+    reg["plone.portal_timezone"] = tz
     return current_tz
 
 
 def set_env_timezone(tz):
     if tz is None:
-        os.environ.pop('TZ')
+        os.environ.pop("TZ")
         return None
-    current_tz = os.environ.get('TZ', None)
-    os.environ['TZ'] = tz
+    current_tz = os.environ.get("TZ", None)
+    os.environ["TZ"] = tz
     return current_tz
 
 
 def os_zone():
-    return os.environ['TZ'] if 'TZ' in os.environ.keys() else None
+    return os.environ["TZ"] if "TZ" in os.environ.keys() else None
 
 
 def make_fake_response(request):
@@ -60,7 +51,7 @@ def make_fake_response(request):
     headers = {}
     output = []
 
-    class Response(object):
+    class Response:
         def setHeader(self, header, value):
             headers[header] = value
 
@@ -79,66 +70,61 @@ class PAEventLayer(PloneSandboxLayer):
         self.ostz = os_zone()
 
         # Install products that use an old-style initialize() function
-        installProduct(app, 'Products.DateRecurringIndex')
+        installProduct(app, "Products.DateRecurringIndex")
 
         # Load ZCML
         import plone.app.event
+
         self.loadZCML(package=plone.app.event, context=configurationContext)
 
     def setUpPloneSite(self, portal):
-        self.applyProfile(portal, 'plone.app.event:default')
-        set_timezone(tz='UTC')
+        self.applyProfile(portal, "plone.app.event:default")
+        set_timezone(tz="UTC")
 
     def tearDownZope(self, app):
         # Uninstall old-style Products
-        uninstallProduct(app, 'Products.DateRecurringIndex')
+        uninstallProduct(app, "Products.DateRecurringIndex")
 
         # reset OS TZ
         if self.ostz:
-            os.environ['TZ'] = self.ostz
-        elif 'TZ' in os.environ:
-            del os.environ['TZ']
+            os.environ["TZ"] = self.ostz
+        elif "TZ" in os.environ:
+            del os.environ["TZ"]
 
 
 PAEvent_FIXTURE = PAEventLayer()
 PAEvent_INTEGRATION_TESTING = IntegrationTesting(
-    bases=(PAEvent_FIXTURE,),
-    name="PAEvent:Integration")
+    bases=(PAEvent_FIXTURE,), name="PAEvent:Integration"
+)
 
 
 class PAEventDXLayer(PloneSandboxLayer):
-
     defaultBases = (PAEvent_FIXTURE,)
 
     def setUpZope(self, app, configurationContext):
         self.ostz = os_zone()
-        # Load ZCML
-        import plone.app.contenttypes
-        self.loadZCML(package=plone.app.contenttypes,
-                      context=configurationContext)
-
         import plone.app.event.dx
-        self.loadZCML(package=plone.app.event.dx,
-                      context=configurationContext)
+
+        self.loadZCML(package=plone.app.event.dx, context=configurationContext)
 
     def setUpPloneSite(self, portal):
-        self.applyProfile(portal, 'plone.app.contenttypes:default')
-        self.applyProfile(portal, 'plone.app.event:testing')
-        set_timezone(tz='UTC')
+        self.applyProfile(portal, "plone.app.event:testing")
+        set_timezone(tz="UTC")
 
 
 PAEventDX_FIXTURE = PAEventDXLayer()
 PAEventDX_INTEGRATION_TESTING = IntegrationTesting(
-    bases=(PAEventDX_FIXTURE,),
-    name="PAEventDX:Integration")
+    bases=(PAEventDX_FIXTURE,), name="PAEventDX:Integration"
+)
 # Functional testing needed for tests, with explicit transaction commits.
 PAEventDX_FUNCTIONAL_TESTING = FunctionalTesting(
-    bases=(PAEventDX_FIXTURE,),
-    name="PAEventDX:Functional")
+    bases=(PAEventDX_FIXTURE,), name="PAEventDX:Functional"
+)
 PAEventDX_ROBOT_TESTING = FunctionalTesting(
     bases=(
         PAEventDX_FIXTURE,
         AUTOLOGIN_LIBRARY_FIXTURE,
         WSGI_SERVER_FIXTURE,
     ),
-    name="plone.app.event.dx:Robot")
+    name="plone.app.event.dx:Robot",
+)
