@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-from mock import Mock
 from OFS.SimpleItem import SimpleItem
 from plone.app.event.base import get_events
 from plone.app.event.base import RET_MODE_ACCESSORS
@@ -22,15 +20,15 @@ from plone.event.interfaces import IEventAccessor
 from plone.event.interfaces import IEventRecurrence
 from plone.event.interfaces import IOccurrence
 from plone.event.interfaces import IRecurrenceSupport
-from plone.testing.z2 import Browser
+from plone.testing.zope import Browser
+from unittest import mock
+from unittest.mock import Mock
 from zope.annotation.interfaces import IAnnotations
 from zope.interface import alsoProvides
 from zope.publisher.interfaces.browser import IBrowserView
 
 import datetime
-import mock
 import pytz
-import six
 import transaction
 import unittest
 import zope.component
@@ -40,8 +38,8 @@ TZNAME = "Europe/Vienna"
 
 
 class TestTraversalDX(AbstractSampleDataEvents):
-    """Test OccurrenceTraverser with DX objects.
-    """
+    """Test OccurrenceTraverser with DX objects."""
+
     layer = PAEventDX_FUNCTIONAL_TESTING
 
     @property
@@ -50,14 +48,11 @@ class TestTraversalDX(AbstractSampleDataEvents):
 
     def test_no_occurrence(self):
         self.assertRaises(
-            AttributeError,
-            self.occ_traverser_1.publishTraverse,
-            self.request,
-            'foo'
+            AttributeError, self.occ_traverser_1.publishTraverse, self.request, "foo"
         )
 
     def test_default_views(self):
-        view = self.occ_traverser_1.publishTraverse(self.request, 'event_view')
+        view = self.occ_traverser_1.publishTraverse(self.request, "event_view")
         self.assertTrue(IBrowserView.providedBy(view))
 
     def test_occurrence(self):
@@ -68,22 +63,26 @@ class TestTraversalDX(AbstractSampleDataEvents):
         self.assertRaises(
             AttributeError,
             self.occ_traverser_1.publishTraverse,
-            self.request, '2000-01-01')
+            self.request,
+            "2000-01-01",
+        )
 
         # Try to traverse to future occurrence
         self.assertRaises(
             AttributeError,
             self.occ_traverser_1.publishTraverse,
-            self.request, '2030-01-01')
+            self.request,
+            "2030-01-01",
+        )
 
         # Traverse to existent occurrence
-        item = self.occ_traverser_1.publishTraverse(self.request, '2013-05-07')
+        item = self.occ_traverser_1.publishTraverse(self.request, "2013-05-07")
         self.assertTrue(IOccurrence.providedBy(item))
         self.assertEqual(type(self.now_event), type(item.aq_parent))
 
         # Test attributes of Occurrence
-        self.assertEqual(item.portal_type, 'Occurrence')
-        self.assertEqual(item.id, '2013-05-07')
+        self.assertEqual(item.portal_type, "Occurrence")
+        self.assertEqual(item.id, "2013-05-07")
         delta = datetime.timedelta(days=2)
         self.assertEqual(item.start, self.now + delta)
         self.assertEqual(item.end, self.now + delta + self.duration)
@@ -91,32 +90,26 @@ class TestTraversalDX(AbstractSampleDataEvents):
     def test_occurrence_accessor(self):
         start = self.now
         end = self.future
-        occ = Occurrence('ignored', start, end)
+        occ = Occurrence("ignored", start, end)
         occ = occ.__of__(self.now_event)
         acc_occ = IEventAccessor(occ)
         acc_ctx = IEventAccessor(self.now_event)
         self.assertEqual(acc_occ.start, acc_ctx.start)
-        self.assertEqual(acc_occ.url, 'http://nohost/plone/now/ignored')
+        self.assertEqual(acc_occ.url, "http://nohost/plone/now/ignored")
 
     def test_traverse_occurrence(self):
         transaction.commit()
         browser = Browser(self.app)
-        browser.addHeader(
-            'Authorization', 'Basic %s:%s' % (TEST_USER_ID, TEST_USER_PASSWORD)
-        )
-        url = '/'.join([self.now_event.absolute_url(), '2013-05-07'])
+        browser.addHeader("Authorization", f"Basic {TEST_USER_ID}:{TEST_USER_PASSWORD}")
+        url = "/".join([self.now_event.absolute_url(), "2013-05-07"])
         browser.open(url)
         title = self.now_event.title
-        if six.PY2:
-            title = title.encode('ascii')
         self.assertTrue(title in browser.contents)
 
     def test_traverse_occurrence_imagescaling(self):
         self.now_event.image = Mock()
-        occurrence = self.occ_traverser_1.publishTraverse(
-            self.request, '2013-05-07'
-        )
-        image_view = occurrence.restrictedTraverse('@@images')
+        occurrence = self.occ_traverser_1.publishTraverse(self.request, "2013-05-07")
+        image_view = occurrence.restrictedTraverse("@@images")
         self.assertEqual(image_view.context, self.now_event)
 
 
@@ -124,8 +117,8 @@ class TestOccurrences(unittest.TestCase):
     layer = PAEventDX_INTEGRATION_TESTING
 
     def setUp(self):
-        self.portal = self.layer['portal']
-        self.request = self.layer['request']
+        self.portal = self.layer["portal"]
+        self.request = self.layer["request"]
 
         set_browserlayer(self.request)
         set_env_timezone(TZNAME)
@@ -135,77 +128,79 @@ class TestOccurrences(unittest.TestCase):
 
         yesterday = now - datetime.timedelta(days=1)
 
-        setRoles(self.portal, TEST_USER_ID, ['Manager'])
+        setRoles(self.portal, TEST_USER_ID, ["Manager"])
         self.daily = createContentInContainer(
             self.portal,
-            'plone.app.event.dx.event',
-            id='daily',
-            title=u'Daily Event',
+            "plone.app.event.dx.event",
+            id="daily",
+            title="Daily Event",
             start=now,
             end=now + datetime.timedelta(hours=1),
-            location=u'Vienna',
-            recurrence='RRULE:FREQ=DAILY;COUNT=4',
+            location="Vienna",
+            recurrence="RRULE:FREQ=DAILY;COUNT=4",
         )
         self.interval = createContentInContainer(
             self.portal,
-            'plone.app.event.dx.event',
-            id='interval',
-            title=u'Interval Event',
+            "plone.app.event.dx.event",
+            id="interval",
+            title="Interval Event",
             start=yesterday,
             end=yesterday + datetime.timedelta(hours=1),
-            location=u'Halle',
-            recurrence='RRULE:FREQ=DAILY;INTERVAL=2;COUNT=5',
+            location="Halle",
+            recurrence="RRULE:FREQ=DAILY;INTERVAL=2;COUNT=5",
         )
 
         self.now = now
         self.yesterday = yesterday
 
     def test_get_occurrences(self):
-        res = get_events(self.portal, ret_mode=RET_MODE_ACCESSORS,
-                         expand=True)
+        res = get_events(self.portal, ret_mode=RET_MODE_ACCESSORS, expand=True)
         self.assertEqual(len(res), 9)
-        res = get_events(self.portal, start=self.now,
-                         ret_mode=RET_MODE_ACCESSORS, expand=True)
+        res = get_events(
+            self.portal, start=self.now, ret_mode=RET_MODE_ACCESSORS, expand=True
+        )
         self.assertEqual(len(res), 8)
 
-        res = get_events(self.portal, ret_mode=RET_MODE_ACCESSORS,
-                         expand=True, limit=5)
+        res = get_events(self.portal, ret_mode=RET_MODE_ACCESSORS, expand=True, limit=5)
         self.assertEqual(len(res), 5)
         self.assertTrue(IEventAccessor.providedBy(res[0]))
 
     def test_event_summary_occurrences(self):
         createContentInContainer(
             self.portal,
-            'plone.app.event.dx.event',
-            id='many',
-            title=u'Interval Event',
-            location=u'Brisbane',
-            recurrence='RRULE:FREQ=DAILY;COUNT=1000'
+            "plone.app.event.dx.event",
+            id="many",
+            title="Interval Event",
+            location="Brisbane",
+            recurrence="RRULE:FREQ=DAILY;COUNT=1000",
         )
 
         view = zope.component.getMultiAdapter(
-            (self.portal['interval'], self.request), name='event_summary')
+            (self.portal["interval"], self.request), name="event_summary"
+        )
         result = view.next_occurrences
         # altogether 5 occurrences, start occurrence is included
         self.assertEqual(5, len(result))
 
         view = zope.component.getMultiAdapter(
-            (self.portal['many'], self.request), name='event_summary')
+            (self.portal["many"], self.request), name="event_summary"
+        )
 
         # Number of shown occurrences should match max_occurrences setting
         self.assertEqual(len(view.next_occurrences), view.max_occurrences)
         # num_more_occurrences should return number of remaining occurrences
-        self.assertEqual(
-            view.num_more_occurrences, 1000 - view.max_occurrences)
+        self.assertEqual(view.num_more_occurrences, 1000 - view.max_occurrences)
 
     def test_event_summary_occurrences_next_upcoming(self):
-        event = IEventAccessor(self.portal['daily'])
+        event = IEventAccessor(self.portal["daily"])
 
         date = patched_now()
-        with mock.patch('plone.app.event.dx.behaviors.localized_now',
-                        return_value=date):
+        with mock.patch(
+            "plone.app.event.dx.behaviors.localized_now", return_value=date
+        ):
             view = zope.component.getMultiAdapter(
-                (self.portal['daily'], self.request), name='event_summary')
+                (self.portal["daily"], self.request), name="event_summary"
+            )
             # altogether 4 occurrences, start occurrence is included
             self.assertEqual(4, len(view.next_occurrences))
             self.assertEqual(event.start, date)
@@ -213,10 +208,12 @@ class TestOccurrences(unittest.TestCase):
 
         IAnnotations(self.request).clear()  # clear cache
         next_date = patched_now() + datetime.timedelta(hours=24)
-        with mock.patch('plone.app.event.dx.behaviors.localized_now',
-                        return_value=next_date):
+        with mock.patch(
+            "plone.app.event.dx.behaviors.localized_now", return_value=next_date
+        ):
             view = zope.component.getMultiAdapter(
-                (self.portal['daily'], self.request), name='event_summary')
+                (self.portal["daily"], self.request), name="event_summary"
+            )
             # 3 occurrences remaining
             self.assertEqual(3, len(view.next_occurrences))
             self.assertEqual(event.start, next_date)
@@ -225,23 +222,27 @@ class TestOccurrences(unittest.TestCase):
 
         IAnnotations(self.request).clear()  # clear cache
         next_date = patched_now() + datetime.timedelta(days=10)
-        with mock.patch('plone.app.event.dx.behaviors.localized_now',
-                        return_value=next_date):
+        with mock.patch(
+            "plone.app.event.dx.behaviors.localized_now", return_value=next_date
+        ):
             view = zope.component.getMultiAdapter(
-                (self.portal['daily'], self.request), name='event_summary')
+                (self.portal["daily"], self.request), name="event_summary"
+            )
             # no occurrences remaining, show all original 4
             self.assertEqual(4, len(view.next_occurrences))
             self.assertEqual(event.start, date)
             self.assertEqual(event.end, date + datetime.timedelta(hours=1))
 
     def test_event_summary_occurrences_whole_day(self):
-        self.portal['daily'].whole_day = True
+        self.portal["daily"].whole_day = True
 
         date = patched_now()
-        with mock.patch('plone.app.event.dx.behaviors.localized_now',
-                        return_value=date):
+        with mock.patch(
+            "plone.app.event.dx.behaviors.localized_now", return_value=date
+        ):
             view = zope.component.getMultiAdapter(
-                (self.portal['daily'], self.request), name='event_summary')
+                (self.portal["daily"], self.request), name="event_summary"
+            )
             # altogether 4 occurrences, start occurrence is included
             self.assertEqual(4, len(view.next_occurrences))
             for occurrence in view.next_occurrences:
@@ -252,10 +253,12 @@ class TestOccurrences(unittest.TestCase):
 
         IAnnotations(self.request).clear()  # clear cache
         next_date = patched_now() + datetime.timedelta(hours=24)
-        with mock.patch('plone.app.event.dx.behaviors.localized_now',
-                        return_value=next_date):
+        with mock.patch(
+            "plone.app.event.dx.behaviors.localized_now", return_value=next_date
+        ):
             view = zope.component.getMultiAdapter(
-                (self.portal['daily'], self.request), name='event_summary')
+                (self.portal["daily"], self.request), name="event_summary"
+            )
             # 3 occurrences remaining
             self.assertEqual(3, len(view.next_occurrences))
             for occurrence in view.next_occurrences:
@@ -266,10 +269,12 @@ class TestOccurrences(unittest.TestCase):
 
         IAnnotations(self.request).clear()  # clear cache
         next_date = patched_now() + datetime.timedelta(days=10)
-        with mock.patch('plone.app.event.dx.behaviors.localized_now',
-                        return_value=next_date):
+        with mock.patch(
+            "plone.app.event.dx.behaviors.localized_now", return_value=next_date
+        ):
             view = zope.component.getMultiAdapter(
-                (self.portal['daily'], self.request), name='event_summary')
+                (self.portal["daily"], self.request), name="event_summary"
+            )
             # no occurrences remaining, show all original 4
             self.assertEqual(4, len(view.next_occurrences))
             for occurrence in view.next_occurrences:
@@ -284,16 +289,15 @@ class MockEvent(SimpleItem):
 
 
 class TestRecurrenceSupport(unittest.TestCase):
-
     layer = PAEvent_INTEGRATION_TESTING
 
     def setUp(self):
-        self.tz = tz = pytz.timezone('Europe/Vienna')
+        self.tz = tz = pytz.timezone("Europe/Vienna")
         duration = datetime.timedelta(days=4)
         data = MockEvent()
         data.start = datetime.datetime(2011, 11, 11, 11, 00, tzinfo=tz)
         data.end = data.start + duration
-        data.recurrence = 'RRULE:FREQ=DAILY;COUNT=4'
+        data.recurrence = "RRULE:FREQ=DAILY;COUNT=4"
         alsoProvides(data, IEvent, IEventRecurrence)
         self.data = data
 
@@ -338,8 +342,7 @@ class TestRecurrenceSupport(unittest.TestCase):
         # Test with range
         rs = datetime.datetime(2011, 11, 11, 11, 0, tzinfo=self.tz)
         re = datetime.datetime(2011, 11, 12, 11, 0, tzinfo=self.tz)
-        result = IRecurrenceSupport(self.data).occurrences(range_start=rs,
-                                                           range_end=re)
+        result = IRecurrenceSupport(self.data).occurrences(range_start=rs, range_end=re)
         result = list(result)  # cast generator to list
 
         self.assertEqual(2, len(result))
